package com.massa.mrules.droolsfight.beans;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Input / Output data container.
 */
public class MeasureBean {
	//Input data
	private MeasureData measure;

	//Output data
	private int nbBlocking;
	private List<MeasureError> errors;
	private String airQuality;

	//For testing
	private int expectedNbBlocking;
	private List<MeasureError> expectedErrors;
	private String expectedAirQuality;

	// Ref data.
	private Set<String> pollutantTypes = new HashSet<String>(Arrays.asList(new String[] {
			"PM10", "SO2", "CO2", "CO", "O3", "NO2"
	}));

	public MeasureBean() {
	}

	public MeasureBean(final MeasureData measure) {
		this.measure = measure;
	}

	//For testing purposes.
	public void reset() {
		this.nbBlocking = 0;
		this.errors = null;
		this.airQuality = null;
	}

	public MeasureData getMeasure() {
		return this.measure;
	}

	public void setMeasure(final MeasureData measure) {
		this.measure = measure;
	}

	public List<MeasureError> getErrors() {
		return this.errors;
	}

	public void setErrors(final List<MeasureError> errors) {
		this.errors = errors;
	}

	public void addError(final MeasureError error) {
		if (this.errors == null) {
			this.errors = new ArrayList<MeasureError>();
		}
		this.errors.add(error);
	}

	public void addExpectedError(final MeasureError error) {
		if (this.expectedErrors == null) {
			this.expectedErrors = new ArrayList<MeasureError>();
		}
		this.expectedErrors.add(error);
	}

	public List<MeasureError> getExpectedErrors() {
		return this.expectedErrors;
	}

	public void setExpectedErrors(final List<MeasureError> expectedErrors) {
		this.expectedErrors = expectedErrors;
	}

	public Set<String> getPollutantTypes() {
		return this.pollutantTypes;
	}

	public void setPollutantTypes(final Set<String> pollutantTypes) {
		this.pollutantTypes = pollutantTypes;
	}

	public int getNbBlocking() {
		return this.nbBlocking;
	}

	public void setNbBlocking(final int nbBlockink) {
		this.nbBlocking = nbBlockink;
	}

	public String getAirQuality() {
		return this.airQuality;
	}

	public void setAirQuality(final String airQuality) {
		this.airQuality = airQuality;
	}

	public int getExpectedNbBlocking() {
		return this.expectedNbBlocking;
	}

	public void setExpectedNbBlocking(final int expectedNbBlockink) {
		this.expectedNbBlocking = expectedNbBlockink;
	}

	public String getExpectedAirQuality() {
		return this.expectedAirQuality;
	}

	public void setExpectedAirQuality(final String expectedAirQuality) {
		this.expectedAirQuality = expectedAirQuality;
	}

}
